<?php

/**
 * @file
 * alpha deltapay menu items.
 */

define('AB_SUCCESFUL_TRANSACTION', 1);
define('AB_ERROR_TRANSACTION', 2);
define('AB_TRANSACTION_CANCELED', 3);

/**
 * Hook function for succesful order.
 */
function commerce_alphabank_redirect_complete() {
  // Get the _POST data from alphabank.
  $data = $_POST;

  $order_id = isset($data['Param1']) ? check_plain($data['Param1']) : '';
  watchdog('commerce_alphabank', 'Receiving new order notification for order @order_id.', array('@order_id' => $order_id));

  $order = commerce_static_checkout_url_load_order_or_die($order_id);

  $payment_status = isset($data['Result']) ? check_plain($data['Result']) : '';
  $delta_pay_id = isset($data['DeltaPayId']) ? check_plain($data['DeltaPayId']) : '';
  $payment_amount = isset($data['Charge']) ? check_plain($data['Charge']) : '';
  $payment_amount = str_replace(',', '.', $payment_amount);
  $payment_currency = isset($data['Currency']) ? check_plain($data['Currency']) : '';
  $payment_currency_code = isset($data['CurrencyCode']) ? check_plain($data['CurrencyCode']) : '';

  if ($payment_status != AB_SUCCESFUL_TRANSACTION) {
    commerce_static_checkout_url_redirect_with_error('alphabank', $order, 'Wrong POST DATA', TRUE);
  }

  $transaction = commerce_payment_transaction_new('commerce_alphabank_redirect', $order_id);
  $transaction->instance_id = $delta_pay_id;
  $transaction->amount = floatval($payment_amount) * 100;
  $transaction->currency_code = $payment_currency_code;
  $transaction->payload[REQUEST_TIME] = $data;
  $transaction->status = COMMERCE_PAYMENT_STATUS_SUCCESS;
  $transaction->remote_id = $delta_pay_id;
  $transaction->remote_status = $payment_status;
  $transaction->message = t('Payment was successful');
  $result = commerce_payment_transaction_save($transaction);
  commerce_checkout_complete($order);

  commerce_static_checkout_url_redirect_with_success('alphabank');
}

/**
 * Hook function for order with failure.
 */
function commerce_alphabank_redirect_error() {
  // Get the _POST data from alphabank.
  $data = $_POST;

  $order_id = isset($data['Param1']) ? check_plain($data['Param1']) : '';

  $order = commerce_static_checkout_url_load_order_or_die($order_id);

  $payment_status = isset($data['Result']) ? check_plain($data['Result']) : '';
  // $delta_pay_id = $_POST['DeltaPayId'];
  // NOT RETURNED ON CANCEL!
  $delta_pay_id = -1;
  $error_message = isset($data['ErrorMessage']) ? check_plain($data['ErrorMessage']) : '';

  if ($payment_status != AB_ERROR_TRANSACTION) {
    commerce_static_checkout_url_redirect_with_error('alphabank', $order, 'Wrong POST DATA', TRUE);
  }

  $transaction = commerce_payment_transaction_new('commerce_alphabank_redirect', $order_id);
  $transaction->instance_id = -1;
  $transaction->payload[REQUEST_TIME] = $data;
  $transaction->status = COMMERCE_PAYMENT_STATUS_FAILURE;
  $transaction->remote_id = $delta_pay_id;
  $transaction->remote_status = $payment_status;
  $transaction->message = $error_message;
  $result = commerce_payment_transaction_save($transaction);

  commerce_static_checkout_url_redirect_with_error('alphabank', $order, $error_message);
}

/**
 * Hook function for canceled order.
 */
function commerce_alphabank_redirect_cancel() {
  // Get the _POST data from alphabank.
  $data = $_POST;

  $order_id = isset($data['Param1']) ? check_plain($data['Param1']) : '';

  $order = commerce_static_checkout_url_load_order_or_die($order_id);

  $payment_status = isset($data['Result']) ? check_plain($data['Result']) : '';
  // $delta_pay_id = $_POST['DeltaPayId'];
  // NOT RETURNED ON CANCEL.
  $delta_pay_id = -1;

  if ($payment_status != AB_TRANSACTION_CANCELED) {
    commerce_static_checkout_url_redirect_with_error('alphabank', $order, 'Wrong POST DATA', TRUE);
  }

  $transaction = commerce_payment_transaction_new('commerce_alphabank_redirect', $order_id);
  $transaction->instance_id = -1;
  $transaction->payload[REQUEST_TIME] = $data;
  $transaction->status = COMMERCE_PAYMENT_STATUS_FAILURE;
  $transaction->remote_id = $delta_pay_id;
  $transaction->remote_status = $payment_status;
  $transaction->message = t('Payment was cancelled');
  $result = commerce_payment_transaction_save($transaction);

  commerce_static_checkout_url_redirect_with_cancel('alphabank', $order);
}
